@@ -11,9 +11,8 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 config opt/kde/share/config/kdm/kdmrc.new
+config opt/kde/share/config/kdm/backgroundrc.new
 
-( cd opt/kde/bin ; rm -rf filesharelist )
-( cd opt/kde/bin ; ln -sf fileshareset filesharelist )
 ( cd opt/kde/bin ; rm -rf kinfocenter )
 ( cd opt/kde/bin ; ln -sf kcontrol kinfocenter )
 ( cd opt/kde/lib ; rm -rf libkickermain.so.1 )
@@ -34,18 +33,30 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/lib ; ln -sf libksplashthemes.so.0.0.0 libksplashthemes.so.0 )
 ( cd opt/kde/lib ; rm -rf libkateutils.so.0 )
 ( cd opt/kde/lib ; ln -sf libkateutils.so.0.0.0 libkateutils.so.0 )
+( cd opt/kde/lib ; rm -rf libkhotkeys_shared.so.1 )
+( cd opt/kde/lib ; ln -sf libkhotkeys_shared.so.1.0.0 libkhotkeys_shared.so.1 )
 ( cd opt/kde/lib ; rm -rf libksgrd.so )
 ( cd opt/kde/lib ; ln -sf libksgrd.so.1.2.0 libksgrd.so )
 ( cd opt/kde/lib ; rm -rf libkickermain.so )
 ( cd opt/kde/lib ; ln -sf libkickermain.so.1.0.0 libkickermain.so )
 ( cd opt/kde/lib ; rm -rf libtaskmanager.so )
 ( cd opt/kde/lib ; ln -sf libtaskmanager.so.1.0.0 libtaskmanager.so )
+( cd opt/kde/lib ; rm -rf libkasbar.so )
+( cd opt/kde/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so )
+( cd opt/kde/lib ; rm -rf libkfontinst.so )
+( cd opt/kde/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so )
 ( cd opt/kde/lib ; rm -rf libksgrd.so.1 )
 ( cd opt/kde/lib ; ln -sf libksgrd.so.1.2.0 libksgrd.so.1 )
 ( cd opt/kde/lib ; rm -rf libtaskbar.so.1 )
 ( cd opt/kde/lib ; ln -sf libtaskbar.so.1.2.0 libtaskbar.so.1 )
+( cd opt/kde/lib ; rm -rf libkfontinst.so.0 )
+( cd opt/kde/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so.0 )
 ( cd opt/kde/lib ; rm -rf libtaskmanager.so.1 )
 ( cd opt/kde/lib ; ln -sf libtaskmanager.so.1.0.0 libtaskmanager.so.1 )
+( cd opt/kde/lib ; rm -rf libkasbar.so.1 )
+( cd opt/kde/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so.1 )
+( cd opt/kde/lib ; rm -rf libkhotkeys_shared.so )
+( cd opt/kde/lib ; ln -sf libkhotkeys_shared.so.1.0.0 libkhotkeys_shared.so )
 ( cd opt/kde/lib ; rm -rf libtaskbar.so )
 ( cd opt/kde/lib ; ln -sf libtaskbar.so.1.2.0 libtaskbar.so )
 ( cd opt/kde/lib ; rm -rf libkateinterfaces.so )
@@ -64,12 +75,16 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/share/doc/HTML/en/kxkb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdcop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdcop ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdesu ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kfind ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/klipper ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kompmgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kompmgr ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/konsole ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/khelpcenter/faq ; rm -rf common )
@@ -88,6 +103,8 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/share/doc/HTML/en/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kioslave ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/knetattach ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/smb ; rm -rf common )
@@ -178,14 +195,14 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdeprint ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kicker ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kpager ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kdebase-apidocs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdebase-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kwrite ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/ksplashml ; rm -rf common )
@@ -214,12 +231,16 @@ config opt/kde/share/config/kdm/kdmrc.new
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/partitions ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kinfocenter/cdinfo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kinfocenter/cdinfo ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/memory ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/ioports ; rm -rf common )
